@@ -16,7 +16,6 @@ from types import SimpleNamespace
 import threading
 import datetime
 from traitlets import Dict,Unicode,Instance,TraitType,Type,default
-from traitlets.config.configurable import Configurable
 from notebook.services.contents.manager import ContentsManager
 from collections import namedtuple
 from tornado import gen
@@ -32,9 +31,9 @@ Config = namedtuple('Config', [
  'prefix', 'region', 'bucket_name', 'host_name', 'cortx_authenticator',
     'multipart_uploads', 'endpoint_url'
 ])
-CredentialConfig = namedtuple('CredentialConfig', [
-    'access_key_id', 'secret_access_key'
-])
+# CredentialConfig = namedtuple('CredentialConfig', [
+#     'access_key_id', 'secret_access_key'
+# ])
 
 
 class ExpiringDict:
